@@ -8,7 +8,7 @@ require Exporter;
 use vars qw($VERSION @ISA);
 @ISA = 'Acme::Colour';
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 sub default {
   return 'orange';
@@ -29,8 +29,10 @@ sub closest {
   return 'orange';
 }
 
-1;
+*_closest = \*closest;
+
 __END__
+
 =head1 NAME
 
 Acme::Orange - Like Acme::Colour but only for important colours
@@ -58,6 +60,8 @@ Methods are as Acme::Colour
 
 Acme::Colour by Leon Brocard
 
+Acme::Tango by Peter Sergeant
+
 =head1 BUGS
 
 Can't do overloaded constants. Yet
